@@ -9,11 +9,12 @@ from typing import Iterable
 from jb_declarative_formatters.parsers.cpp_parser import CppParser
 from jb_declarative_formatters.parsers.type_name_parser import parse_type_name_template
 from jb_declarative_formatters.type_viz_generated_method import GeneratedMethodDefinition
+from jb_lldb_commands_utils import make_absolute_name, register_lldb_commands
 from renderers.jb_lldb_builtin_formatters import *
 from renderers.jb_lldb_declarative_formatters_loaders import *
 from renderers.jb_lldb_declarative_formatters_manager import *
 from renderers.jb_lldb_format import update_value_dynamic_state
-from renderers.jb_lldb_logging import get_suppress_errors
+from renderers.jb_lldb_logging_manager import RENDER_LOG
 from renderers.jb_lldb_natvis_formatters import NatVisDescriptor, NatVisSyntheticItemDescriptor
 from renderers.jb_lldb_natvis_synthetic_item_type_viz_cache import NatvisSyntheticItemTypeVizCache
 from renderers.jb_lldb_top_level_lazy_declarations import LLDBTopLevelLazyDeclarations
@@ -22,7 +23,7 @@ lldb_formatters_manager: FormattersManager
 
 
 def __lldb_init_module(debugger: lldb.SBDebugger, internal_dict):
-    log('JetBrains declarative formatters LLDB module registered into {}', str(debugger))
+    RENDER_LOG.info('JetBrains declarative formatters LLDB module registered into %s', debugger)
 
     commands_list = {
         make_absolute_name(__name__, '_cmd_loaders_add'): 'jb_renderers_loaders_add',
@@ -56,7 +57,6 @@ def __lldb_init_module(debugger: lldb.SBDebugger, internal_dict):
 
 
 def _cmd_loaders_add(debugger, command, exe_ctx, result, internal_dict):
-    # raise NotImplementedError("jb_renderers_loaders_add is not implemented yet")
     help_message = 'Usage: jb_renderers_loaders_add <loader_tag> <module> <funcname>'
     cmd = shlex.split(command)
     if len(cmd) < 1:
@@ -262,8 +262,7 @@ def declarative_summary(val: lldb.SBValue, _):
     except IgnoreSynthProvider:
         return ''
     except:
-        if not get_suppress_errors():
-            raise
+        RENDER_LOG.exception("Cannot generate summary")
         return ''
 
 
@@ -358,7 +357,7 @@ class DeclarativeSynthProvider(object):
 
     def _create_children_provider(self) -> None:
         try:
-            log("Retrieving children of value named '{}'...", self.val_non_synth.GetName())
+            RENDER_LOG.info("Retrieving children of value named '%s'...", self.val_non_synth.GetName())
 
             provider = get_viz_descriptor_provider()
             vis_descriptor = provider.get_matched_visualizers(self.val_non_synth, False)
@@ -369,8 +368,7 @@ class DeclarativeSynthProvider(object):
             pass
         except Exception as e:
             # some unexpected error happened
-            if not get_suppress_errors():
-                log("{}", traceback.format_exc())
+            RENDER_LOG.exception("Cannot create children provider")
 
         if not self.children_provider:
             self.children_provider = StructChildrenProvider(self.val_non_synth)
@@ -419,7 +417,7 @@ def _try_find_matched_natvis_visualizer_for_base(value_type: lldb.SBType) -> Opt
         try:
             base_type_name_template = parse_type_name_template(base_type_name)
         except Exception as e:
-            log('Parsing typename {} failed: {}', base_type_name, e)
+            RENDER_LOG.error('Parsing typename %s failed: %s', base_type_name, e)
             raise
 
         viz_candidates = _get_matched_type_visualizers(base_type_name_template, True)
@@ -438,15 +436,15 @@ def _try_get_matched_visualizers(value_type: lldb.SBType, format_spec: int) -> O
 
     if not (format_spec & eFormatRawView):
         value_type_name = CppParser.remove_type_class_specifier(value_type.GetName())
-        log("Trying to find natvis visualizer for type: '{}'...", value_type_name)
+        RENDER_LOG.info("Trying to find natvis visualizer for type: '%s'...", value_type_name)
         try:
             type_name_template = parse_type_name_template(value_type_name)
         except Exception as e:
-            log('Parsing typename {} failed: {}', value_type_name, e)
+            RENDER_LOG.error('Parsing typename %s failed: %s', value_type_name, e)
             raise
         viz_candidates = _get_matched_type_visualizers(type_name_template)
         if viz_candidates:
-            log("Found natvis visualizer for type: '{}'", value_type_name)
+            RENDER_LOG.info("Found natvis visualizer for type: '%s'", value_type_name)
             return NatVisDescriptor(viz_candidates, type_name_template)
 
     return _try_get_matched_builtin_visualizer(value_type, format_spec)
@@ -454,13 +452,13 @@ def _try_get_matched_visualizers(value_type: lldb.SBType, format_spec: int) -> O
 
 def _try_get_matched_builtin_visualizer(value_type: lldb.SBType, format_spec: int):
     value_type_name = value_type.GetName()
-    log("Trying to find builtin visualizer for type: '{}'", value_type_name)
+    RENDER_LOG.info("Trying to find builtin visualizer for type: '%s'", value_type_name)
 
     type_class = value_type.GetTypeClass()
     if type_class == lldb.eTypeClassTypedef:
         value_typedef_type = value_type.GetTypedefedType()
         value_typedef_type_name = value_typedef_type.GetName()
-        log("Type '{}' is typedef to type '{}'", value_type_name, value_typedef_type_name)
+        RENDER_LOG.info("Type '%s' is typedef to type '%s'", value_type_name, value_typedef_type_name)
         if value_typedef_type_name != value_type_name:
             return _try_get_matched_visualizers(value_typedef_type, format_spec)
 
